@@ -1,10 +1,12 @@
-// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// SPDX-License-Identifier: Apache-2.0
+// 
+// Copyright 2008-2016 Conrad Sanderson (https://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
-// http://www.apache.org/licenses/LICENSE-2.0
+// https://www.apache.org/licenses/LICENSE-2.0
 // 
 // Unless required by applicable law or agreed to in writing, software
 // distributed under the License is distributed on an "AS IS" BASIS,
@@ -22,7 +24,7 @@
 template<typename T1>
 arma_warn_unused
 inline
-typename enable_if2< is_real<typename T1::elem_type>::value, Col<typename T1::pod_type> >::result
+typename enable_if2< is_blas_real<typename T1::elem_type>::value, Col<typename T1::pod_type> >::result
 eigs_sym
   (
   const SpBase<typename T1::elem_type,T1>& X,
@@ -31,7 +33,7 @@ eigs_sym
   const eigs_opts                          opts = eigs_opts()
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Mat<typename T1::elem_type> eigvec;
   Col<typename T1::pod_type > eigval;
@@ -53,9 +55,9 @@ eigs_sym
 
 //! this form is deprecated; use eigs_sym(X, n_eigvals, form, opts) instead
 template<typename T1>
-arma_deprecated
+[[deprecated]]
 inline
-typename enable_if2< is_real<typename T1::elem_type>::value, Col<typename T1::pod_type> >::result
+typename enable_if2< is_blas_real<typename T1::elem_type>::value, Col<typename T1::pod_type> >::result
 eigs_sym
   (
   const SpBase<typename T1::elem_type,T1>& X,
@@ -64,7 +66,7 @@ eigs_sym
   const typename T1::elem_type             tol
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   eigs_opts opts;
   opts.tol = tol;
@@ -77,7 +79,7 @@ eigs_sym
 template<typename T1>
 arma_warn_unused
 inline
-typename enable_if2< is_real<typename T1::elem_type>::value, Col<typename T1::pod_type> >::result
+typename enable_if2< is_blas_real<typename T1::elem_type>::value, Col<typename T1::pod_type> >::result
 eigs_sym
   (
   const SpBase<typename T1::elem_type,T1>& X,
@@ -86,7 +88,7 @@ eigs_sym
   const eigs_opts                          opts = eigs_opts()
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::pod_type T;
   
@@ -109,7 +111,7 @@ eigs_sym
 //! eigenvalues of symmetric real sparse matrix X
 template<typename T1>
 inline
-typename enable_if2< is_real<typename T1::elem_type>::value, bool >::result
+typename enable_if2< is_blas_real<typename T1::elem_type>::value, bool >::result
 eigs_sym
   (
            Col<typename T1::pod_type >&    eigval,
@@ -119,7 +121,7 @@ eigs_sym
   const eigs_opts                          opts = eigs_opts()
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Mat<typename T1::elem_type> eigvec;
   
@@ -130,7 +132,7 @@ eigs_sym
   if(status == false)
     {
     eigval.soft_reset();
-    arma_debug_warn_level(3, "eigs_sym(): decomposition failed");
+    arma_warn(3, "eigs_sym(): decomposition failed");
     }
   
   return status;
@@ -140,9 +142,9 @@ eigs_sym
 
 //! this form is deprecated; use eigs_sym(eigval, X, n_eigvals, form, opts) instead
 template<typename T1>
-arma_deprecated
+[[deprecated]]
 inline
-typename enable_if2< is_real<typename T1::elem_type>::value, bool >::result
+typename enable_if2< is_blas_real<typename T1::elem_type>::value, bool >::result
 eigs_sym
   (
            Col<typename T1::pod_type >&    eigval,
@@ -152,7 +154,7 @@ eigs_sym
   const typename T1::elem_type             tol
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   eigs_opts opts;
   opts.tol = tol;
@@ -164,7 +166,7 @@ eigs_sym
 
 template<typename T1>
 inline
-typename enable_if2< is_real<typename T1::elem_type>::value, bool >::result
+typename enable_if2< is_blas_real<typename T1::elem_type>::value, bool >::result
 eigs_sym
   (
            Col<typename T1::pod_type >&    eigval,
@@ -174,7 +176,7 @@ eigs_sym
   const eigs_opts                          opts = eigs_opts()
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::pod_type T;
   
@@ -185,7 +187,7 @@ eigs_sym
   if(status == false)
     {
     eigval.soft_reset();
-    arma_debug_warn_level(3, "eigs_sym(): decomposition failed");
+    arma_warn(3, "eigs_sym(): decomposition failed");
     }
   
   return status;
@@ -196,7 +198,7 @@ eigs_sym
 //! eigenvalues and eigenvectors of symmetric real sparse matrix X
 template<typename T1>
 inline
-typename enable_if2< is_real<typename T1::elem_type>::value, bool >::result
+typename enable_if2< is_blas_real<typename T1::elem_type>::value, bool >::result
 eigs_sym
   (
            Col<typename T1::pod_type >&    eigval,
@@ -207,9 +209,9 @@ eigs_sym
   const eigs_opts                          opts = eigs_opts()
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
-  arma_debug_check( void_ptr(&eigval) == void_ptr(&eigvec), "eigs_sym(): parameter 'eigval' is an alias of parameter 'eigvec'" );
+  arma_conform_check( void_ptr(&eigval) == void_ptr(&eigvec), "eigs_sym(): parameter 'eigval' is an alias of parameter 'eigvec'" );
   
   sp_auxlib::form_type form_val = sp_auxlib::interpret_form_str(form);
   
@@ -219,7 +221,7 @@ eigs_sym
     {
     eigval.soft_reset();
     eigvec.soft_reset();
-    arma_debug_warn_level(3, "eigs_sym(): decomposition failed");
+    arma_warn(3, "eigs_sym(): decomposition failed");
     }
   
   return status;
@@ -229,9 +231,9 @@ eigs_sym
 
 //! this form is deprecated; use eigs_sym(eigval, eigvec, X, n_eigvals, form, opts) instead
 template<typename T1>
-arma_deprecated
+[[deprecated]]
 inline
-typename enable_if2< is_real<typename T1::elem_type>::value, bool >::result
+typename enable_if2< is_blas_real<typename T1::elem_type>::value, bool >::result
 eigs_sym
   (
            Col<typename T1::pod_type >&    eigval,
@@ -242,7 +244,7 @@ eigs_sym
   const typename T1::elem_type             tol
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   eigs_opts opts;
   opts.tol = tol;
@@ -254,7 +256,7 @@ eigs_sym
 
 template<typename T1>
 inline
-typename enable_if2< is_real<typename T1::elem_type>::value, bool >::result
+typename enable_if2< is_blas_real<typename T1::elem_type>::value, bool >::result
 eigs_sym
   (
            Col<typename T1::pod_type >&    eigval,
@@ -265,11 +267,11 @@ eigs_sym
   const eigs_opts                          opts = eigs_opts()
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   typedef typename T1::pod_type T;
   
-  arma_debug_check( void_ptr(&eigval) == void_ptr(&eigvec), "eigs_sym(): parameter 'eigval' is an alias of parameter 'eigvec'" );
+  arma_conform_check( void_ptr(&eigval) == void_ptr(&eigvec), "eigs_sym(): parameter 'eigval' is an alias of parameter 'eigvec'" );
   
   const bool status = sp_auxlib::eigs_sym(eigval, eigvec, X, n_eigvals, T(sigma), opts);
   
@@ -277,7 +279,7 @@ eigs_sym
     {
     eigval.soft_reset();
     eigvec.soft_reset();
-    arma_debug_warn_level(3, "eigs_sym(): decomposition failed");
+    arma_warn(3, "eigs_sym(): decomposition failed");
     }
   
   return status;
