@@ -1,12 +1,12 @@
 // SPDX-License-Identifier: Apache-2.0
 // 
-// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// Copyright 2008-2016 Conrad Sanderson (https://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
-// http://www.apache.org/licenses/LICENSE-2.0
+// https://www.apache.org/licenses/LICENSE-2.0
 // 
 // Unless required by applicable law or agreed to in writing, software
 // distributed under the License is distributed on an "AS IS" BASIS,
@@ -23,11 +23,8 @@
 
 //! for tiny square matrices, size <= 4x4
 template<const bool do_trans_A=false, const bool use_alpha=false, const bool use_beta=false>
-class gemm_emul_tinysq
+struct gemm_emul_tinysq
   {
-  public:
-  
-  
   template<typename eT, typename TA, typename TB>
   arma_cold
   inline
@@ -42,7 +39,7 @@ class gemm_emul_tinysq
     const eT       beta  = eT(0)
     )
     {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
     
     switch(A.n_rows)
       {
@@ -64,10 +61,8 @@ class gemm_emul_tinysq
 
 //! emulation of gemm(), for non-complex matrices only, as it assumes only simple transposes (ie. doesn't do hermitian transposes)
 template<const bool do_trans_A=false, const bool do_trans_B=false, const bool use_alpha=false, const bool use_beta=false>
-class gemm_emul_large
+struct gemm_emul_large
   {
-  public:
-  
   template<typename eT, typename TA, typename TB>
   arma_hot
   inline
@@ -82,7 +77,7 @@ class gemm_emul_large
     const eT       beta  = eT(0)
     )
     {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
 
     const uword A_n_rows = A.n_rows;
     const uword A_n_cols = A.n_cols;
@@ -102,7 +97,7 @@ class gemm_emul_large
         
         for(uword col_B=0; col_B < B_n_cols; ++col_B)
           {
-          const eT acc = op_dot::direct_dot_arma(B_n_rows, A_rowdata, B.colptr(col_B));
+          const eT acc = op_dot::direct_dot(B_n_rows, A_rowdata, B.colptr(col_B));
           
                if( (use_alpha == false) && (use_beta == false) )  { C.at(row_A,col_B) =       acc;                          }
           else if( (use_alpha == true ) && (use_beta == false) )  { C.at(row_A,col_B) = alpha*acc;                          }
@@ -122,7 +117,7 @@ class gemm_emul_large
         
         for(uword col_B=0; col_B < B_n_cols; ++col_B)
           {
-          const eT acc = op_dot::direct_dot_arma(B_n_rows, A_coldata, B.colptr(col_B));
+          const eT acc = op_dot::direct_dot(B_n_rows, A_coldata, B.colptr(col_B));
           
                if( (use_alpha == false) && (use_beta == false) )  { C.at(col_A,col_B) =       acc;                          }
           else if( (use_alpha == true ) && (use_beta == false) )  { C.at(col_A,col_B) = alpha*acc;                          }
@@ -158,7 +153,7 @@ class gemm_emul_large
         
         for(uword col_A=0; col_A < A_n_cols; ++col_A)
           {
-          const eT acc = op_dot::direct_dot_arma(A_n_rows, B_rowdata, A.colptr(col_A));
+          const eT acc = op_dot::direct_dot(A_n_rows, B_rowdata, A.colptr(col_A));
           
                if( (use_alpha == false) && (use_beta == false) )  { C.at(col_A,row_B) =       acc;                          }
           else if( (use_alpha == true ) && (use_beta == false) )  { C.at(col_A,row_B) = alpha*acc;                          }
@@ -174,11 +169,8 @@ class gemm_emul_large
 
 
 template<const bool do_trans_A=false, const bool do_trans_B=false, const bool use_alpha=false, const bool use_beta=false>
-class gemm_emul
+struct gemm_emul
   {
-  public:
-  
-  
   template<typename eT, typename TA, typename TB>
   arma_hot
   inline
@@ -194,7 +186,7 @@ class gemm_emul
     const typename arma_not_cx<eT>::result* junk = nullptr
     )
     {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
     arma_ignore(junk);
     
     gemm_emul_large<do_trans_A, do_trans_B, use_alpha, use_beta>::apply(C, A, B, alpha, beta);
@@ -217,7 +209,7 @@ class gemm_emul
     const typename arma_cx_only<eT>::result* junk = nullptr
     )
     {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
     arma_ignore(junk);
     
     // "better than nothing" handling of hermitian transposes for complex number matrices
@@ -243,17 +235,15 @@ class gemm_emul
 //! Matrix 'C' is assumed to have been set to the correct size (ie. taking into account transposes)
 
 template<const bool do_trans_A=false, const bool do_trans_B=false, const bool use_alpha=false, const bool use_beta=false>
-class gemm
+struct gemm
   {
-  public:
-  
   template<typename eT, typename TA, typename TB>
   inline
   static
   void
   apply_blas_type( Mat<eT>& C, const TA& A, const TB& B, const eT alpha = eT(1), const eT beta = eT(0) )
     {
-    arma_extra_debug_sigprint();
+    arma_debug_sigprint();
     
     if( (A.n_rows <= 4) && (A.n_rows == A.n_cols) && (A.n_rows == B.n_rows) && (B.n_rows == B.n_cols) && (is_cx<eT>::no) ) 
       {
@@ -274,9 +264,9 @@ class gemm
       {
       #if defined(ARMA_USE_ATLAS)
         {
-        arma_extra_debug_print("atlas::cblas_gemm()");
+        arma_debug_print("atlas::cblas_gemm()");
         
-        arma_debug_assert_atlas_size(A,B);
+        arma_conform_assert_atlas_size(A,B);
         
         atlas::cblas_gemm<eT>
           (
@@ -298,9 +288,9 @@ class gemm
         }
       #elif defined(ARMA_USE_BLAS)
         {
-        arma_extra_debug_print("blas::gemm()");
+        arma_debug_print("blas::gemm()");
         
-        arma_debug_assert_blas_size(A,B);
+        arma_conform_assert_blas_size(A,B);
         
         const char trans_A = (do_trans_A) ? ( is_cx<eT>::yes ? 'C' : 'T' ) : 'N';
         const char trans_B = (do_trans_B) ? ( is_cx<eT>::yes ? 'C' : 'T' ) : 'N';
@@ -316,8 +306,8 @@ class gemm
         
         const eT local_beta  = (use_beta) ? beta : eT(0);
         
-        arma_extra_debug_print( arma_str::format("blas::gemm(): trans_A = %c") % trans_A );
-        arma_extra_debug_print( arma_str::format("blas::gemm(): trans_B = %c") % trans_B );
+        arma_debug_print( arma_str::format("blas::gemm(): trans_A: %c") % trans_A );
+        arma_debug_print( arma_str::format("blas::gemm(): trans_B: %c") % trans_B );
         
         blas::gemm<eT>
           (
